// Dynare code for problem set 2, question 2 (markup shocks)

// (1) declare endogenous variables

var        c, k, l, i, y, w, r, pi, m, z;                                                    

// (2) declare exogenous variables (shocks)

varexo     em, ez;                               

// (3) declare parameters

parameters alpha, beta, delta, phim, phiz, psi, sigma, sigmaem, sigmaez, zbar, mbar; 

alpha    = 0.30;    // capital share in production function
beta     = 1/1.01;  // time discount factor
delta    = 0.02;    // depreciation rate
phim     = 0.95;    // AR(1) coefficient for log markup
phiz     = 0.95;    // AR(1) coefficient for log productivity
psi      = 1.00;    // inverse of Frisch elasticity of labor supply
sigma    = 1.00;    // coefficient of relative risk aversion
sigmaem  = 0.01;    // standard deviation of innovations to markups
sigmaez  = 0.01;    // standard deviation of innovations to productivity

zbar     = 1.00;    // long-run productivity level
mbar     = 1.15;    // long-run markup

// (4) declare the model equations

model;                                   

// resource constraint
exp(c) + exp(k) = exp(z)*(exp(k(-1))^alpha)*(exp(l)^(1-alpha))+(1-delta)*exp(k(-1));
                  
// consumption Euler equation
exp(c)^(-sigma) = beta*(exp(c(+1))^(-sigma))*(alpha*exp(z(+1)-m(+1))*(exp(k)^(alpha-1))*(exp(l(+1))^(1-alpha))+1-delta);

// labor supply
exp(c)*exp(l)^psi = (1-alpha)*exp(z-m)*(exp(k(-1))^alpha)*(exp(l)^(-alpha));

// output
exp(y) = exp(z)*(exp(k(-1))^alpha)*(exp(l)^(1-alpha));

// investment
exp(i) = exp(k) - (1-delta)*exp(k(-1));

// wage
exp(w) = (1-alpha)*exp(y-m-l);

// rental rate
exp(r) = alpha*exp(y-m-k(-1));

// profits
exp(pi) = (exp(m)-1)*exp(y-m);

// law of motion markups
m = (1-phim)*log(mbar)+phim*m(-1)+em;

// law of motion productivity
z = (1-phiz)*log(zbar)+phiz*z(-1)+ez;

end;


// (5) solve the steady state 
initval;
c  = 0.98;
k  = 3.85;
l  = -0.02;
i  = -0.75;
y  = 1.15;
w  = 0.8;
r  = -3.9;
pi = 0.115;
m  = 0.15;
z  = 0;
em = 0;
ez = 0;
end;

steady;

// specify variance of shocks

shocks;
var em = sigmaem^2;
var ez = sigmaez^2;
end;

// (6) solve the dynamics
stoch_simul(order=1,irf=100);



 

