%%%%% ps2_question2: markup shocks
clearvars;
close all;

%%%%% run dynare on .mod file
%     suppress log file and warnings

dynare ps2_question2.mod nowarn nolog  

%     c, k, i, y, l, w, r, pi, m, z;  

%%%%% recover coefficients of interest from dynare structures

%%%%% my ordering

n_c = 1; n_k = 2; n_l = 3; n_m=9; n_z=10; 

%%%%% matrices for state-space representation
% s=As(-1) + Be, x=C*s(-1) + De, s = (k,z), x=c etc

A = [oo_.dr.ghx(oo_.dr.inv_order_var(n_k),:);
     oo_.dr.ghx(oo_.dr.inv_order_var(n_m),:);
     oo_.dr.ghx(oo_.dr.inv_order_var(n_z),:)];
 
B = [oo_.dr.ghu(oo_.dr.inv_order_var(n_k),:);
     oo_.dr.ghu(oo_.dr.inv_order_var(n_m),:);
     oo_.dr.ghu(oo_.dr.inv_order_var(n_z),:)];
 
C = [oo_.dr.ghx(oo_.dr.inv_order_var(n_c),:);
     oo_.dr.ghx(oo_.dr.inv_order_var(n_l),:)];

D = [oo_.dr.ghu(oo_.dr.inv_order_var(n_c),:);
     oo_.dr.ghu(oo_.dr.inv_order_var(n_l),:)]; 
 
%%%%% in lecture notation

psi_kk = A(1,1);
psi_km = A(1,2)/A(2,2); 
psi_kz = A(1,3)/A(3,3); 

psi_ck = C(1,1);
psi_cm = D(1,1);
psi_cz = D(1,2);

psi_nk = C(2,1);
psi_nm = D(2,1);
psi_nz = D(2,2);


%%%%% Do a simple impulse response to a unit productivity shock

T = 100;          %% calculate for T periods after shock

time = (-1:1:T)'; %% steady state at t=-1, shock at t=0

shockz    = zeros(size(time));
shockm    = zeros(size(time));
shockz(2) = 0.01;  %% set the impulse
shockm(2) = 0;  

zt   = zeros(size(time));
mt   = zeros(size(time));
kt   = zeros(size(time));
nt   = zeros(size(time));
ct   = zeros(size(time));
yt   = zeros(size(time));
it   = zeros(size(time));
wt   = zeros(size(time));
rt   = zeros(size(time));
pit  = zeros(size(time));

for t=2:length(time)
    
    zt(t) = phiz*zt(t-1) + shockz(t);                   %% productivity
    mt(t) = phim*mt(t-1) + shockm(t);                   %% markup
    
    kt(t) = psi_kk*kt(t-1) + psi_km*mt(t)+ psi_kz*zt(t); %% capital stock
    ct(t) = psi_ck*kt(t-1) + psi_cm*mt(t)+ psi_cz*zt(t); %% consumption
    nt(t) = psi_nk*kt(t-1) + psi_nm*mt(t)+ psi_nz*zt(t); %% employment
    
    it(t) = (kt(t) - (1-delta)*kt(t-1))/delta;          %% investment
    
    yt(t) = zt(t) + alpha*kt(t-1) + (1-alpha)*nt(t);    %% output 
    
    wt(t) = zt(t) - mt(t) + alpha*(kt(t-1)-nt(t));      %% wage rate
    rt(t) = zt(t) - mt(t) + (alpha-1)*(kt(t-1)-nt(t));  %% rental rate
    
    pit(t) = yt(t) + (1/(mbar-1))*mt(t);                %% profits 
      
end    

figure(3)
set(gcf,'DefaultLineLineWidth', 2);
subplot(1,2,1)
plot(time,zt,'b-' ,time,ct,'g-',time,yt,'r-',time,it,'c-',time,nt,'m-',time,zeros(size(time)),'k--')
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 2)
xlabel('periods after shock','Interpreter','latex')
ylabel('log-deviation from steady state','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('productivity','consumption','output','investment','employment','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 100, -0.01 0.06])
subplot(1,2,2)
plot(time,kt,'-',time,wt,'g-',time,rt,'r-',time,pit,'m-',time,zeros(size(time)),'k--');
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 2)
xlabel('periods after shock','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('capital','wage','rental rate','profits','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 100, -0.01 0.06])

%%%%% Do a simple impulse response to a unit markup shock

T = 100;          %% calculate for T periods after shock

time = (-1:1:T)'; %% steady state at t=-1, shock at t=0

shockz    = zeros(size(time));
shockm    = zeros(size(time));
shockz(2) = 0;  %% set the impulse
shockm(2) = 0.01;  

zt   = zeros(size(time));
mt   = zeros(size(time));
kt   = zeros(size(time));
nt   = zeros(size(time));
ct   = zeros(size(time));
yt   = zeros(size(time));
it   = zeros(size(time));

for t=2:length(time)
    
    zt(t) = phiz*zt(t-1) + shockz(t);                   %% productivity
    mt(t) = phim*mt(t-1) + shockm(t);                   %% markup
    
    kt(t) = psi_kk*kt(t-1) + psi_km*mt(t)+ psi_kz*zt(t); %% capital stock
    ct(t) = psi_ck*kt(t-1) + psi_cm*mt(t)+ psi_cz*zt(t); %% consumption
    nt(t) = psi_nk*kt(t-1) + psi_nm*mt(t)+ psi_cz*zt(t); %% employment
    
    it(t) = (kt(t) - (1-delta)*kt(t-1))/delta;          %% investment
    
    yt(t) = zt(t) + alpha*kt(t-1) + (1-alpha)*nt(t);    %% output 
    
    wt(t) = zt(t) - mt(t) + alpha*(kt(t-1)-nt(t));      %% wage rate
    rt(t) = zt(t) - mt(t) + (alpha-1)*(kt(t-1)-nt(t));  %% rental rate
      
end    

figure(4)
set(gcf,'DefaultLineLineWidth', 2);
subplot(1,2,1)
plot(time,mt,'b-' ,time,ct,'g-',time,yt,'r-',time,it,'c-',time,nt,'m-',time,zeros(size(time)),'k--')
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 2)
xlabel('periods after shock','Interpreter','latex')
ylabel('log-deviation from steady state','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('markup','consumption','output','investment','employment','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 100, -0.04 0.015])
subplot(1,2,2)
plot(time,kt,'-',time,wt,'g-',time,rt,'r-',time,pit,'m-',time,zeros(size(time)),'k--');
set(get(gcf,'CurrentAxes'),'FontSize',16,'LineWidth', 2)
xlabel('periods after shock','Interpreter','latex')
set(gca,'DefaultTextInterpreter', 'latex','TickLabelInterpreter','latex')
l = legend('capital','wage','rental rate','profits','Location','Best');
set(l,'Interpreter','latex');
axis([-5, 100, -0.04 0.015])

